import "Turbine.UI";
import "Turbine.UI.Lotro";
import "MathPlugins.RTStuff";

-- the control that displays the map of a region with its corresponding locations. each location is active or not, depending on the togglebutton
MapControl = class( Turbine.UI.Window );

function MapControl:Constructor( location, parent )
	Turbine.UI.Window.Constructor( self );
	self:SetSize(800,630);
	
	self.pointCoords = {};
	self.pointLabels = {};
	self.pointLocations = {};
	self.pointButtons = {};
	
	self.location = location;

	self.locked = false;

	for key,value in pairs( mapdata[location] ) do
		table.insert(self.pointCoords,key);
		table.insert(self.pointLocations,value);
	end
	
	self.pointNr = tableLength(self.pointCoords)
	
	self.lockIcon = Turbine.UI.Button();
	self.lockIcon:SetParent( self );
	self.lockIcon:SetSize( 20,20 );
	self.lockIcon:SetPosition( 762,0 );
	self.lockIcon:SetBackground( strings["unlock"] );
	self.lockIcon.MouseClick = function( sender,args )
		self:SetLocked(not self.locked);
	end
	
	for i=1,self.pointNr do
		self.pointButtons[i] = MapButton( self, self.pointLocations[i][1], 											self.pointLocations[i][2] );
		self.pointLabels[i] = Turbine.UI.Label();
		self.pointLabels[i]:SetPosition( self.pointButtons[i]:GetLeft()+self.pointButtons[i]:GetWidth()+3, self.pointButtons[i]:GetTop()+self.pointButtons[i]:GetHeight()/2 );
		self.pointLabels[i]:SetParent( self );
		self.pointLabels[i]:SetVisible( false );
		self.pointLabels[i]:SetSize( 80,10 );
		self.pointLabels[i]:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );
		self.pointLabels[i]:SetText( self.pointCoords[i] );
		if self.pointCoords[i]=="70.3S 46.2W" then
			self.pointLabels[i]:SetText( "Nimrond cave" );
			self.pointLabels[i]:SetSize( 90,10 );
		end
		self.pointLabels[i]:SetBackColor( Turbine.UI.Color(1,0.1,0.1,0.1) );
		self.pointLabels[i]:SetZOrder( self.pointButtons[i]:GetZOrder()+1 );
		self.pointButtons[i].MouseEnter = function(  )
			self.pointLabels[i]:SetVisible( true );
		end
		self.pointButtons[i].MouseLeave = function()
			self.pointLabels[i]:SetVisible( false );
		end
	end
	
	if location=="Angmar" then
		self.epiButton = MapButton( self, 415,372 );
		self.epiButton.Activate();
		self.epiButton:SetLocked( true );
		self.epiLabel = Turbine.UI.Label();
		self.epiLabel:SetPosition( self.epiButton:GetLeft()+self.epiButton:GetWidth()+3, 
			self.epiButton:GetTop()+self.epiButton:GetHeight()/2 );
		self.epiLabel:SetParent( self );
		self.epiLabel:SetVisible( false );
		self.epiLabel:SetSize( 145,12 );
		self.epiLabel:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );
		self.epiLabel:SetBackColor( Turbine.UI.Color(1,0.1,0.1,0.1) );
		self.epiLabel:SetZOrder( self.epiButton:GetZOrder()+1 );
		self.epiLabel:SetText( "Epilogue: 0.9N 27.2W" );
		self.epiButton.MouseEnter = function(  )
			self.epiLabel:SetVisible( true );
		end
		self.epiButton.MouseLeave = function()
			self.epiLabel:SetVisible( false );
		end
	end
		
	
	self.rightClick = Turbine.UI.ContextMenu();
	self.menu1 = Turbine.UI.MenuItem( strings[locale]["clearmap"] );
	self.menu1.Click = function(sender,args)
		self:SetActive( {} );
	end
	self.menu2 = Turbine.UI.MenuItem( strings[locale]["fullmap"] );
	self.menu2.Click = function(sender,args)
		self:SetInactive( {} );
	end
	self.menu3 = Turbine.UI.MenuItem( strings[locale]["lockmsg"] );
	self.menu3.Click = function(sender,args)
		self:SetLocked( not self.locked );
	end	
	self.rightClick:GetItems():Add(self.menu1);
	self.rightClick:GetItems():Add(self.menu2);
	self.rightClick:GetItems():Add(self.menu3);
	
	local menu = self.rightClick
	
	self.MouseClick = function( sender, args )
		parent:Activate();
		if (args.Button == Turbine.UI.MouseButton.Right) then
			menu:ShowMenu();
		end
	end
end

function MapControl:AddActive( coordlist )
	if not self.locked then
		for i=1,self.pointNr do
			if tableContains( coordlist, self.pointCoords[i] ) then
				self.pointButtons[i].Activate();
			end
		end
	end
end

function MapControl:SetActive( coordlist )
	if not self.locked then
		for i=1,self.pointNr do
			if tableContains( coordlist, self.pointCoords[i] ) then
				self.pointButtons[i].Activate();
			else
				self.pointButtons[i].Deactivate();
			end
		end
	end
end

function MapControl:SetInactive( coordlist )
	if not self.locked then
		for i=1,self.pointNr do
			if tableContains( coordlist, self.pointCoords[i] ) then
				self.pointButtons[i].Deactivate();
			else
				self.pointButtons[i].Activate();
			end
		end
	end
end

function MapControl:SetLocked( bool )
	self.locked = bool;
	if bool then
		self.menu3:SetText( strings[locale]["unlockmsg"] );
		self.lockIcon:SetBackground( strings["lock"] );
	else
		self.menu3:SetText( strings[locale]["lockmsg"] );
		self.lockIcon:SetBackground( strings["unlock"] );
	end
	for i=1,self.pointNr do
		self.pointButtons[i]:SetLocked( bool );
	end
end

function MapControl:GetActive( )
	local t = {}
	for i=1,self.pointNr do
		if self.pointButtons[i].isactive then
			table.insert(t, self.pointCoords[i])
		end
	end
	return t
end